<?php
///////////////////////////////////////////////////////////////////////////

#require_once 'lib/abstract_preloaded_regular_screen.php';
require_once 'lib/tv/tv_channel_list_screen.php';
///////////////////////////////////////////////////////////////////////////

class LVTV_TvChannelListScreen extends TvChannelListScreen implements UserInputHandler{
    const ID = 'lvtv_tv_channel_list';

    public static function get_media_url_str($group_id){
        return MediaURL::encode(
            array(
                'screen_id' => self::ID,
                'group_id'  => $group_id,
            )
        );
    }

    ///////////////////////////////////////////////////////////////////////

    protected $tv;
    private $session;
    private $time_shift;
    private $buff_time;
    ///////////////////////////////////////////////////////////////////////

    public function __construct(Tv $tv, $folder_views,$session){
        parent::__construct($tv, $folder_views,self::ID);

        $this->tv = $tv;
	$this->session = $session;

        UserInputHandlerRegistry::get_instance()->register_handler($this);
    }

    ///////////////////////////////////////////////////////////////////////

    public function get_action_map(MediaURL $media_url, &$plugin_cookies){
        $actions = array();
        $actions[GUI_EVENT_KEY_ENTER] = ActionFactory::tv_play();
        $actions[GUI_EVENT_KEY_PLAY] = ActionFactory::tv_play();

        if ($this->tv->is_favorites_supported())
        {
            $add_favorite_action =
                UserInputHandlerRegistry::create_action(
                    $this, 'add_favorite');
            $add_favorite_action['caption'] = 'Добавить в избранное';


            $popup_menu_action =
                UserInputHandlerRegistry::create_action(
                    $this, 'popup_menu');

            $actions[GUI_EVENT_KEY_D_BLUE] = $add_favorite_action;
            $actions[GUI_EVENT_KEY_POPUP_MENU] = $popup_menu_action;
        }
	$info_action = UserInputHandlerRegistry::create_action(
                $this, 'info');
	$info_action['caption'] = 'Информация о канале';
        $actions[GUI_EVENT_KEY_INFO] = $info_action;
        $settings_action =
                UserInputHandlerRegistry::create_action(
                    $this, 'settings');
        $settings_action['caption'] = 'Настройки'; 
        $actions[GUI_EVENT_KEY_B_GREEN] = $settings_action;	           
        return $actions;
    }
    public function get_handler_id()
    { return self::ID; }

    private function get_sel_item_update_action(&$user_input, &$plugin_cookies,$sel_increment=null)
    {
        $parent_media_url = MediaURL::decode($user_input->parent_media_url);
        $sel_ndx = $user_input->sel_ndx;
        if ($sel_ndx < 0)
            $sel_ndx = 0;
        $group = $this->tv->get_group($parent_media_url->group_id);
        $channels = $group->get_channels($plugin_cookies);

        $items[] = $this->get_regular_folder_item($group,
            $channels->get_by_ndx($sel_ndx), $plugin_cookies);
        $range = HD::create_regular_folder_range($items,
            $sel_ndx, $channels->size());

        return ActionFactory::update_regular_folder($range, false);
    }

    ///////////////////////////////////////////////////////////////////////

    private function get_regular_folder_item($group, $c, &$plugin_cookies)
    {
        return array
        (
            PluginRegularFolderItem::media_url =>
                MediaURL::encode(
                    array(
                        'channel_id' => $c->get_id(),
                        'group_id' => $group->get_id())),
            PluginRegularFolderItem::caption => $c->get_title(),
            PluginRegularFolderItem::view_item_params => array
            (
                ViewItemParams::icon_path => $c->get_icon_url(),
                ViewItemParams::item_detailed_icon_path => $c->get_icon_url(),
            ),
            PluginRegularFolderItem::starred =>
                $this->tv->is_favorite_channel_id(
                    $c->get_id(), $plugin_cookies),
        );
    }
    public function handle_user_input(&$user_input, &$plugin_cookies)
    {
        hd_print('Tv favorites: handle_user_input:');
        foreach ($user_input as $key => $value)
            hd_print("  $key => $value");

        if ($user_input->control_id === 'info')
	{
        
            if (!isset($user_input->selected_media_url))
                return null;

            $media_url = MediaURL::decode($user_input->selected_media_url);
            $channel_id = $media_url->channel_id;

            $channels = $this->tv->get_channels();
            $c = $channels->get($channel_id);
            $id = $c->get_id();
            $title = $c->get_title();
	    $buff = $c->get_buffering_ms();

            return ActionFactory::show_title_dialog("Канал '$title' (id=$id),buff=$buff");
        }
        elseif ($user_input->control_id === 'popup_menu')
        {
            if (!isset($user_input->selected_media_url))
                return null;

            $media_url = MediaURL::decode($user_input->selected_media_url);
            $channel_id = $media_url->channel_id;

            $is_favorite = $this->tv->is_favorite_channel_id($channel_id, $plugin_cookies);
            $add_favorite_action =
                UserInputHandlerRegistry::create_action(
                    $this, 'add_favorite');
            $add_favorite_caption = 'Добавить в Избранное';
            $menu_items[] = array(
                GuiMenuItemDef::caption => $add_favorite_caption,
                GuiMenuItemDef::action => $add_favorite_action);
            return ActionFactory::show_popup_menu($menu_items);
        }
        elseif ($user_input->control_id === 'settings')
	{
		$time_shift = null;
		$buff_time = null;
		return $this->do_get_edit_settings_action($plugin_cookies, $this);

	}

      	elseif ($user_input->control_id === 'apply_settings')
	{
		if(!is_null($this->time_shift))
		{
			$this->session->set_settings_lvtv('timeshift', $this->time_shift);
			$plugin_cookies->time_shift = $this->time_shift;
		}		
		if(!is_null($this->buff_time))
		{
			$this->session->set_settings_lvtv('http_caching',$this->buff_time );
			$plugin_cookies->buf_time = $this->buff_time;
		}
		$this->tv->unload_channels();
		$this->tv->newload($plugin_cookies);
		return ActionFactory::close_dialog();

	}
        elseif ($user_input->control_id == 'add_favorite')
        {
	    hd_print('добавление в избранное');
            if (!isset($user_input->selected_media_url))
                return null;

            $media_url = MediaURL::decode($user_input->selected_media_url);
            $channel_id = $media_url->channel_id;

            $is_favorite = $this->tv->is_favorite_channel_id($channel_id, $plugin_cookies);
            if ($is_favorite)
            {
                return ActionFactory::show_title_dialog(
                    'Канал уже находится в Избранном',
                    $this->get_sel_item_update_action(
                        $user_input, $plugin_cookies));
            }
            else
            {
                $this->tv->change_tv_favorites(PLUGIN_FAVORITES_OP_ADD,
                    $channel_id, $plugin_cookies);

                return ActionFactory::show_title_dialog(
                    'Канал успешно добавлен в Избранное',
                    $this->get_sel_item_update_action(
                        $user_input, $plugin_cookies));
            }
        }
        elseif ($user_input->control_id == 'timeshift' || 'http_caching')
	{
		$control_id = $user_input->control_id;
		$new_value = $user_input->{$control_id};
		#$this->session->set_settings_lvtv($control_id, $new_value);
		if($user_input->control_id == 'timeshift')
		  $this->time_shift = $new_value;
		if($user_input->control_id == 'http_caching')
		  $this->buff_time = $new_value;
		return;

	}
        return null;
    }

    ///////////////////////////////////////////////////////////////////////
    #public function get_archive(MediaURL $media_url)
    #{
    #    return $this->tv->get_archive($media_url);
    #}
   private function do_get_edit_settings_defs(&$plugin_cookies, $handler, $add_params){
		$defs = array();
		$acc_settings = $this->session->get_settings_lvtv();
		$acc_time_shift = $acc_settings->timeshift;
		$time_shift = isset($acc_time_shift->val) ? intval($acc_time_shift->val) : 0;
		hd_print("time_shift:$time_shift");
		$plugin_cookies->time_shift = $time_shift;
		$time_shift_ops = array();
		foreach ($acc_time_shift->values->children()  as $time_shift_list)
		{
			hd_print("timeshift_val: $time_shift_list");
			$time_shift_ops[intval($time_shift_list)] = strval($time_shift_list);
		}
		$acc_buffer_time = $acc_settings->http_caching;;
		$buffer_time = isset($acc_buffer_time->val) ? intval($acc_buffer_time->val) : 0;
			
		hd_print("buffer_time:$buffer_time");
		$plugin_cookies->buf_time = $buffer_time;
		$buffer_time_ops = array();
		foreach ($acc_buffer_time->values->children() as $buffer_time_list)
		{
			hd_print("buff: $buffer_time_list");
			$buffer_time_ops[intval($buffer_time_list)] = strval($buffer_time_list);
		}
		ControlFactory::add_combobox
			    ($defs,
			     $handler,
			     null,
			    'http_caching',
			    'Время буферизации:',
			    $buffer_time, 
			    $buffer_time_ops,
			    500,
			    false,
			    true
			    );

       		ControlFactory::add_combobox
        			(
            				$defs,
					$handler,
					null,
            				'timeshift',
            				'Таймшифт:',
            				$time_shift,
					$time_shift_ops, 
					500,
					false,
					true
        			);
        	ControlFactory::add_button($defs,
            		$handler, $add_params,
            		'apply_settings', null, 'Применить', 300);
		ControlFactory::add_close_dialog_button($defs,
            		'Отменить', 300);
		#ControlFactory::add_close_dialog_and_apply_button($defs,
            	#	$handler, $add_params,
            	#	'apply_settings', null, 'Применить', 300);

		return $defs;
   }
	
   private function do_get_edit_settings_action(&$plugin_cookies, $handler, $add_params = null){
		$message = 'Настройки';
        	return ActionFactory::show_dialog(
            		$message,
            		$this->do_get_edit_settings_defs(
                	$plugin_cookies, $handler, $add_params),
            		true);

   }
}

///////////////////////////////////////////////////////////////////////////
?>
