<?php
///////////////////////////////////////////////////////////////////////////

require_once 'lib/vod/abstract_vod.php';
require_once 'lib/vod/movie.php';

///////////////////////////////////////////////////////////////////////////

class LVTV_Vod extends AbstractVod {

    private $session;
    public function __construct($session){
        parent::__construct(
            LVTV_Config::VOD_FAVORITES_SUPPORTED,
            LVTV_Config::VOD_MOVIE_PAGE_SUPPORTED,
            true
        );
        
	$this->session = $session;
    }

    ///////////////////////////////////////////////////////////////////////

    public function try_load_movie($movie_id, &$plugin_cookies){
	$this->session->check_login($plugin_cookies);
	$xml = $this->session->get_vod_info($movie_id);
        $movie = new Movie($xml->mid);
	$lvtv_url = $this->session->get_lvtv_url();
        $movie->set_data(
            $xml->title,
            $xml->title_orig,
            $xml->description,
            $lvtv_url.strval($xml->thumb),
            intval($xml->runtime)/60,
            $xml->year,
            $xml->directors,
            $xml->writer,
            $xml->stars,
            $xml->in_dir_str,
            $xml->imdb,
            $xml->kinopoisk,
            $xml->mpaa,
            $xml->country,
            $xml->budget
         );

#        foreach ($xml->series->item as $item)
#        {
	 $url = $xml->url."?".$this->session->get_sid();
	 if (strpos($url,".mp4") == true ||  strpos($url,".m4v")){
	 	$url = str_ireplace("http://","http://mp4://",$url);
	 }
	 
         $movie->add_series_data(
                $xml->mid,
                $xml->title,
                $url,
                true
         );
#        }
	 $this->set_cached_movie($movie);
    }
/*    public function get_vod_stream_url($playback_url, &$plugin_cookies)
    {
        #return $this->session->vod_get_url($playback_url);
        $url = str_ireplace("http://","http://mp4://",$playback_url);
	hd_print("kfkhjdkjhkd:$url");
        return $url;
    }
*/
    public function get_vod_info(MediaURL $media_url, &$plugin_cookies){

       	$movie = $this->get_loaded_movie($media_url->movie_id,$plugin_cookies);
	if ($movie === null){
    	    return null;
        }
        
        $sel_id = isset($media_url->series_id) ? $media_url->series_id : null;
        $buff = 10000;
        hd_print("buffer:$buff");
        return $movie->get_vod_info($sel_id,$buff);
    }


    ///////////////////////////////////////////////////////////////////////
    // Favorites.

    protected function load_favorites(&$plugin_cookies){
	$xml = $this->session->get_vod_favorites();
        $total = intval($xml->total);
        if (!isset($xml->total))
		$total = 0;
        if ($total === 0){
            $this->set_fav_movie_ids(array());
            return;
        }
        
        $fav_movie_ids = array();
	$lvtv_url = $this->session->get_lvtv_url();
	
        foreach ($xml->items->children() as $item){
            $movie_id = intval($item->mid);
            $movie_name = strval($item->title);
	    $poster_url = $lvtv_url.strval($item->thumb);

            $fav_movie_ids[] = $movie_id;
            $this->set_cached_short_movie(
                new ShortMovie($movie_id, $movie_name, $poster_url)
            );
        }
        
        $this->set_fav_movie_ids($fav_movie_ids);
        hd_print('The ' . count($fav_movie_ids) . ' favorite movies loaded.');		
    }

    protected function do_add_favorite_movie($movie_id, &$plugin_cookies){
        $this->session->set_vod_favorites($movie_id);
    }

    protected function do_remove_favorite_movie($movie_id, &$plugin_cookies){
        $this->session->rm_vod_favorites($movie_id);
    }

    ///////////////////////////////////////////////////////////////////////
    // Genres.

/*
    protected function load_genres(&$plugin_cookies)
    {
        $doc = $this->session->api_vod_genres();

        $genres = array();
        foreach ($doc->genres as $genre)
            $genres[$genre->id] = $genre->name;

        return $genres;
    }

    public function get_genre_icon_url($genre_id)
    {
        return $this->session->get_icon('mov_genre_default.png');
    }

    public function get_genre_media_url_str($genre_id)
    {
        return DemoVodListScreen::get_media_url_str('genres', $genre_id);
    }
*/

    ///////////////////////////////////////////////////////////////////////
    // Search.


    public function get_search_media_url_str($pattern){
        return LVTV_VodListScreen::get_media_url_str('search', $pattern);
    }


    ///////////////////////////////////////////////////////////////////////
    // Folder views.

    public function get_vod_list_folder_views(){
        return LVTV_Config::GET_VOD_MOVIE_LIST_FOLDER_VIEWS();
    }

    public function get_archive(MediaURL $media_url){ 
        return $this->session->get_archive();
    }
}

///////////////////////////////////////////////////////////////////////////
?>
