<?php
///////////////////////////////////////////////////////////////////////////

require_once 'lib/abstract_controls_screen.php';

///////////////////////////////////////////////////////////////////////////

class LVTV_VodSearchScreen extends VodSearchScreen {
    const ID = 'vod_search';

    public static function get_media_url_str(){
        return MediaURL::encode(array('screen_id' => self::ID));
    }

    ///////////////////////////////////////////////////////////////////////

    protected $vod;

    public function __construct( Vod $vod ){
        parent::__construct( $vod);

        $this->vod = $vod;
    }

    private function do_get_control_defs(&$plugin_cookies){
        $pattern = '';
        if (isset($plugin_cookies->vod_search_pattern))
            $pattern = $plugin_cookies->vod_search_pattern;

        $defs = array();

       	$show_by_ops = array();

        $sort_by_ops['title'] = 'По названию';
        $sort_by_ops['mid'] = 'По расположению в видеотеке';
        $sort_by_ops['rating'] = 'По рейтингу просмотра';
        $sort_by_ops['created'] = 'По дате добавления';
        $sort_by_ops['updated'] = 'По дате обновления';
        $sort_by_ops['title_orig'] = 'По оригинальному названию';
        $sort_by_ops['mpaa'] = 'По рейтингу mpaa';
        $sort_by_ops['imdb'] = 'По рейнтингу imdb';
        $sort_by_ops['kinopoisk'] = 'По рейтингу kinopoisk';
        $sort_by_ops['budget'] = 'По бюджету фильма';
        $sort_by_ops['year'] = 'По дате выпуска фильма';
	$sort_by = isset($plugin_cookies->search_sort) ? $plugin_cookies->search_sort : 'title';
	
	$this->add_combobox(
            $defs,
            'sort_by',
            'Сортировать по',
            $sort_by, $sort_by_ops, 0, true
        );
        
        $this->add_text_field($defs, 'pattern', 'Введите слово',
            $pattern, false, false, true, true,
            500, false, true
        );
        
        return $defs;
    }

    public function get_control_defs(MediaURL $media_url, &$plugin_cookies){
        $this->vod->folder_entered($media_url, $plugin_cookies);

        return $this->do_get_control_defs($plugin_cookies);
    }

    public function handle_user_input(&$user_input, &$plugin_cookies){
        hd_print('Vod search: handle_user_input:');
        foreach ($user_input as $key => $value){
            hd_print("  $key => $value");
        }

        if ($user_input->action_type === 'apply'){
        
            $control_id = $user_input->control_id;

            if ($control_id === 'pattern'){
                $pattern = $user_input->pattern;

                $plugin_cookies->vod_search_pattern = $pattern;

                hd_print("Vod search: applying pattern '$pattern'");

                $defs = $this->do_get_control_defs($plugin_cookies);

                return ActionFactory::reset_controls(
		    $defs,
                    ActionFactory::open_folder(
                        $this->vod->get_search_media_url_str($pattern),
                        $pattern
                    )
                );
            }
            
        }else if ($user_input->action_type === 'confirm'){
            $control_id = $user_input->control_id;
            $new_value = $user_input->{$control_id};

            if ($control_id === 'pattern'){
                $pattern = $user_input->pattern;
                if (preg_match('/^\s*$/', $pattern)){
                    return ActionFactory::show_error(
			false,
                        'Не заполнено поле поиска.'
                    );
                }
                
            }elseif ($control_id === 'sort_by'){
		$plugin_cookies->search_sort = $new_value;
	    }
        }

        return null;
    }
}

///////////////////////////////////////////////////////////////////////////
?>
